%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generating IRFs from the toy model in "HH Debt Overhang and MP Transmission"
% by Sami Alpanda and Sarah Zubairy (Sep. 2016; revised Apr. 2018)
%
% This version features fixed-rate mortgages and refi choice (0,1)
% This code compares IRFs (shock minus control) to a monetary policy shock 
% starting from low vs. high initial debt in partial eq. model in Section 4.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

repres_agent = 1; %1; %1: representative agent; %0/w: distribution of initial debt
rate_increase = 0;  %1;             %1: rate increase, 0: rate cut

n_periods = 20; %length of IRF
%_________________________________________________________________________
%% Preliminaries

load IRF_R_baseline;
l_IRF_baseline = IRF(:,1);
d_IRF_baseline = IRF(:,2); 
c_IRF_baseline = IRF(:,3); 
R_IRF_baseline = IRF(:,4) .*4; %annualized
Rf_IRF_baseline = IRF(:,5) .*4; 
Rm_IRF_baseline = IRF(:,6) .*4; 
HE_IRF_baseline = IRF(:,7); 
q_IRF_baseline = IRF(:,8); 
y_IRF_baseline = IRF(:,9); 
pie_IRF_baseline = IRF(:,10) .*4;
gamma_shock_baseline = IRF(:,11);
gamma_control_baseline = IRF(:,12);
capphi_shock_baseline = IRF(:,13);
capphi_control_baseline = IRF(:,14);

if rate_increase == 1;
    load IRF_R_rateincrease;
else
    load IRF_R_highdebt;
end
l_IRF_alternative = IRF(:,1);
d_IRF_alternative = IRF(:,2); 
c_IRF_alternative = IRF(:,3); 
R_IRF_alternative = IRF(:,4) .*4; 
Rf_IRF_alternative = IRF(:,5) .*4; 
Rm_IRF_alternative = IRF(:,6) .*4; 
HE_IRF_alternative = IRF(:,7); 
q_IRF_alternative = IRF(:,8); 
y_IRF_alternative = IRF(:,9); 
pie_IRF_alternative = IRF(:,10) .*4;
gamma_shock_alternative = IRF(:,11);
gamma_control_alternative = IRF(:,12);
capphi_shock_alternative = IRF(:,13);
capphi_control_alternative = IRF(:,14);


%cumulative responses
l_cumIRF_baseline = cumsum(l_IRF_baseline);
d_cumIRF_baseline = cumsum(d_IRF_baseline);
c_cumIRF_baseline = cumsum(c_IRF_baseline);
R_cumIRF_baseline = cumsum(R_IRF_baseline) ./4;  %cumulative sum of quarterly raises
Rf_cumIRF_baseline = cumsum(Rm_IRF_baseline) ./4;
Rm_cumIRF_baseline = cumsum(Rm_IRF_baseline) ./4;
HE_cumIRF_baseline = cumsum(HE_IRF_baseline);
q_cumIRF_baseline = cumsum(q_IRF_baseline);
y_cumIRF_baseline = cumsum(y_IRF_baseline);
pie_cumIRF_baseline = cumsum(pie_IRF_baseline) ./4;

l_cumIRF_alternative = cumsum(l_IRF_alternative);
d_cumIRF_alternative = cumsum(d_IRF_alternative);
c_cumIRF_alternative = cumsum(c_IRF_alternative);
R_cumIRF_alternative = cumsum(R_IRF_alternative) ./4;
Rf_cumIRF_alternative = cumsum(Rm_IRF_alternative) ./4;
Rm_cumIRF_alternative = cumsum(Rm_IRF_alternative) ./4;
HE_cumIRF_alternative = cumsum(HE_IRF_alternative);
q_cumIRF_alternative = cumsum(q_IRF_alternative);
y_cumIRF_alternative = cumsum(y_IRF_alternative);
pie_cumIRF_alternative = cumsum(pie_IRF_alternative) ./4;


%relative cumulative responses
l_relcumIRF_baseline = l_cumIRF_baseline./-R_cumIRF_baseline ./4;
d_relcumIRF_baseline = d_cumIRF_baseline./-R_cumIRF_baseline ./4;
c_relcumIRF_baseline = c_cumIRF_baseline./-R_cumIRF_baseline ./4;
R_relcumIRF_baseline = R_cumIRF_baseline./-R_cumIRF_baseline ./4;
Rf_relcumIRF_baseline = Rf_cumIRF_baseline./-R_cumIRF_baseline ./4;
Rm_relcumIRF_baseline = Rm_cumIRF_baseline./-R_cumIRF_baseline ./4;
HE_relcumIRF_baseline = HE_cumIRF_baseline./-R_cumIRF_baseline ./4;
q_relcumIRF_baseline = q_cumIRF_baseline./-R_cumIRF_baseline ./4;
y_relcumIRF_baseline = y_cumIRF_baseline./-R_cumIRF_baseline ./4;
pie_relcumIRF_baseline = pie_cumIRF_baseline./-R_cumIRF_baseline ./4;

l_relcumIRF_alternative = l_cumIRF_alternative./-R_cumIRF_alternative ./4;
d_relcumIRF_alternative = d_cumIRF_alternative./-R_cumIRF_alternative ./4;
c_relcumIRF_alternative = c_cumIRF_alternative./-R_cumIRF_alternative ./4;
R_relcumIRF_alternative = R_cumIRF_alternative./-R_cumIRF_alternative ./4;
Rf_relcumIRF_alternative = Rf_cumIRF_alternative./-R_cumIRF_alternative ./4;
Rm_relcumIRF_alternative = Rm_cumIRF_alternative./-R_cumIRF_alternative ./4;
HE_relcumIRF_alternative = HE_cumIRF_alternative./-R_cumIRF_alternative ./4;
q_relcumIRF_alternative = q_cumIRF_alternative./-R_cumIRF_alternative ./4;
y_relcumIRF_alternative = y_cumIRF_alternative./-R_cumIRF_alternative ./4;
pie_relcumIRF_alternative = pie_cumIRF_alternative./-R_cumIRF_alternative ./4;


%________________________________________________________________________
%% Plot IRFs

time = (0:1:n_periods-1)';
line0 = zeros(n_periods,1);

ii = 2; 
jj = 5;

figure('name','IRFs')
subplot(ii,jj,1)
plot(time,d_IRF_baseline,'-sr',time,d_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('debt')
axis tight

subplot(ii,jj,2)
plot(time,l_IRF_baseline,'-sr',time,l_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('new borrowing')
axis tight

subplot(ii,jj,3)
plot(time,q_IRF_baseline,'-sr',time,q_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('house price')
axis tight

subplot(ii,jj,4)
plot(time,HE_IRF_baseline,'-sr',time,HE_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('home equity')
axis tight

subplot(ii,jj,5)
plot(time,c_IRF_baseline,'-sr',time,c_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('consumption')
axis tight

subplot(ii,jj,6)
plot(time,R_IRF_baseline,'-sr',time,R_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('policy rate')
axis tight

subplot(ii,jj,7)
plot(time,Rf_IRF_baseline,'-sr',time,Rf_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('fixed rate')
axis tight

subplot(ii,jj,8)
plot(time,Rm_IRF_baseline,'-sr',time,Rm_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
title('average int.')
axis tight

subplot(ii,jj,9)
plot(time,gamma_shock_baseline,'-sr',time,gamma_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
axis tight
if repres_agent == 1
    title('indicator: extract equity')
else
    title('share extracting equity')
end

subplot(ii,jj,10)
plot(time,capphi_shock_baseline,'-sr',time,capphi_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
axis tight
if repres_agent == 1
    title('indicator: refinance')
    legend('initial debt at st-st','high initial debt')
else
    title('share refinancing')
    legend('initial debt mean \mu_L','initial debt mean \mu_H')
end
if rate_increase == 1;
    legend('rate cut','rate increase')
end


% subplot(ii,jj,9)
% plot(time,pie_IRF_baseline,'-sr',time,pie_IRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('inflation')
% axis tight

% %________________________________________________________________________
% %% Cumulative IRF plots
% 
% figure('name','Cumulative IRFs')
% subplot(ii,jj,1)
% plot(time,d_cumIRF_baseline,'-sr',time,d_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('debt')
% axis tight
% 
% subplot(ii,jj,2)
% plot(time,l_cumIRF_baseline,'-sr',time,l_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('new borrowing')
% axis tight
% 
% subplot(ii,jj,3)
% plot(time,q_cumIRF_baseline,'-sr',time,q_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('house price')
% axis tight
% 
% subplot(ii,jj,4)
% plot(time,HE_cumIRF_baseline,'-sr',time,HE_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('home equity')
% axis tight
% 
% subplot(ii,jj,5)
% plot(time,c_cumIRF_baseline,'-sr',time,c_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('consumption')
% axis tight
% 
% subplot(ii,jj,6)
% plot(time,R_cumIRF_baseline,'-sr',time,R_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('policy rate')
% axis tight
% 
% subplot(ii,jj,7)
% plot(time,Rf_cumIRF_baseline,'-sr',time,Rf_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('fixed rate')
% axis tight
% 
% subplot(ii,jj,8)
% plot(time,Rm_cumIRF_baseline,'-sr',time,Rm_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('average int.')
% axis tight
% 
% subplot(ii,jj,9)
% plot(time,gamma_shock_baseline,'-sr',time,gamma_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% axis tight
% if repres_agent == 1
%     title('indicator: extract equity')
% else
%     title('share extracting equity')
% end
% 
% subplot(ii,jj,10)
% plot(time,capphi_shock_baseline,'-sr',time,capphi_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% axis tight
% if repres_agent == 1
%     title('indicator: refinance')
%     legend('initial debt at st-st','high initial debt')
% else
%     title('share refinancing')
%     legend('initial debt mean \mu_L','initial debt mean \mu_H')
% end
% if rate_increase == 1;
%     legend('rate cut','rate increase')
% end
% 
% % subplot(ii,jj,11)
% % plot(time,pie_cumIRF_baseline,'-sr',time,pie_cumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% % title('inflation')
% % axis tight
% 
% %________________________________________________________________________
% %% Relative cumulative IRF plots
% 
% figure('name','Relative cumulative IRFs')
% subplot(ii,jj,1)
% plot(time,d_relcumIRF_baseline,'-sr',time,d_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('debt')
% axis tight
% 
% subplot(ii,jj,2)
% plot(time,l_relcumIRF_baseline,'-sr',time,l_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('new borrowing')
% axis tight
% 
% subplot(ii,jj,3)
% plot(time,q_relcumIRF_baseline,'-sr',time,q_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('house price')
% axis tight
% 
% subplot(ii,jj,4)
% plot(time,HE_relcumIRF_baseline,'-sr',time,HE_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('home equity')
% axis tight
% 
% subplot(ii,jj,5)
% plot(time,c_relcumIRF_baseline,'-sr',time,c_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('consumption')
% axis tight
% 
% subplot(ii,jj,6)
% plot(time,R_relcumIRF_baseline,'-sr',time,R_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('policy rate')
% axis tight
% 
% subplot(ii,jj,7)
% plot(time,Rf_relcumIRF_baseline,'-sr',time,Rf_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('fixed rate')
% axis tight
% 
% subplot(ii,jj,8)
% plot(time,Rm_relcumIRF_baseline,'-sr',time,Rm_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% title('average int.')
% axis tight
% 
% subplot(ii,jj,9)
% plot(time,gamma_shock_baseline,'-sr',time,gamma_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% axis tight
% if repres_agent == 1
%     title('indicator: extract equity')
% else
%     title('share extracting equity')
% end
% 
% subplot(ii,jj,10)
% plot(time,capphi_shock_baseline,'-sr',time,capphi_shock_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% axis tight
% if repres_agent == 1
%     title('indicator: refinance')
%     legend('initial debt at st-st','high initial debt')
% else
%     title('share refinancing')
%     legend('initial debt mean \mu_L','initial debt mean \mu_H')
% end
% if rate_increase == 1;
%     legend('rate cut','rate increase')
% end
% 
% % subplot(ii,jj,9)
% % plot(time,pie_relcumIRF_baseline,'-sr',time,pie_relcumIRF_alternative,'-.xb',time,line0,':k','LineWidth',1.5);
% % title('inflation')
% % axis tight
% 
