clear all
close all
clc

timesample=1; % 1 means 1955-2007; 2 means 1969-2007; 3 means 1955-2015
thresholdd=1;  % Check line 102 onwards % 1 means default threshold; 4 means mortgage debt as state variable; 5 means 2 percent above trend
shockchoice=1; % 1 means SVAR shock; 2 means using FFR; 3 means Romer-Romer shock
datafile=1; %1 means main set of variables; 2 means subcomponents of consumption and investment
opt=0; % 0 means Newey-West with bandwidth=i; 1 means optimal bandwidth (takes much longer to run)

episode=4; %ROBUSTNESS CHECK: which high debt episode to reclassify as low debt: 1,2,3 or 4. Note 0 means the default so no reclassification.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hor=16; % horizon for IRFs
clevel= 1.64; % confidence level % 1.96  1.64;
nlag=2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
vdata=xlsread('data.xlsx');
time=vdata(:,1);

if timesample==1
    t1=find(time==1955); %1969
    t2=find(time==2007.75);
elseif timesample==2
    t1=find(time==1969);
    t2=find(time==2007.75);
elseif timesample==3
    t1=find(time==1955);
    t2=find(time==2015.5);
elseif timesample==4
    t1=find(time==1987);
    t2=find(time==2013.75);
elseif timesample==5
    t1=find(time==1990.75);
    t2=find(time==2015.5);
end


vdata=vdata(t1:t2,:);
q=vdata(:,1);
gdp= vdata(:,2); %GDP
cons= vdata(:,3); % CONS	
invest= vdata(:,4); %INVEST	
resinv= vdata(:,5); %RES_INVEST	
rgdp= vdata(:,6); %RGDP	
pgdp= vdata(:,7); %PGDP	
ffr= vdata(:,8); %FFR	
morrate= vdata(:,9); %MORT_RATE	
hrs= vdata(:,10); %HOURS	
wage= vdata(:,11); %WAGES	
% MORT_DEBT_LEVEL	
debt= vdata(:,12); %mortgage debt (level)
% MORT_DEBT_FLOW	
% HP_Case_Shiller	
% HP_Census_Bureau	
hprice= vdata(:,16);% HP_blend	
pop= vdata(:,17); %CNP16OV	
refi= vdata(:,18); %REFI
rrshock= vdata(:,19); %Romer-Romer monetary shock
hhdebt = vdata(:,20);
corpdebt = vdata(:,21);
recession=vdata(:,22);
trend10e6_old= vdata(:,26);% over sample excluding 2008-2015
trend10e4_old=vdata(:,27);% over sample excluding 2008-2015
pcom=vdata(:,28);
cdur=vdata(:,29);
cndur=vdata(:,30);
cserv=vdata(:,31);
nonresinv=vdata(:,32);
hpshiller=vdata(:,33);
hpshillerreal=vdata(:,34);
ffr= vdata(:,35); %include Wu-Xia shadow rate for 2008-2015
trend10e6= vdata(:,36);% over sample upto 2015
trend10e4= vdata(:,37);% over sample upto 2015
%pop=vdata(:,38); % Total population
hhdebtmvg5= vdata(:,39);
heloc=vdata(:,40)./1000;
trend10e5=vdata(:,42);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA TRANSFORMATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lrgdp= log(gdp./pgdp./pop);
lrcon=log(cons./pgdp./pop);
lrinv=log(invest./pgdp./pop);
lrresinv=log(resinv./pgdp./pop);
inf= [NaN; diff(log(pgdp))*4];
lrhprice=log(hprice./pgdp);
%lrdebt=log(debt./pgdp);
lrcd=log(cdur./pgdp./pop);
lrcnd=log(cndur./pgdp./pop);
lrcs=log(cserv./pgdp./pop);
lrnresinv=log(nonresinv./pgdp./pop);
lpcom=log(pcom);
lrhhdebt=log(hhdebt./pgdp);
lrcdebt=log(corpdebt./pgdp);
lpgdp=log(pgdp);
debttogdp=(hhdebt)./gdp*100;
debtgrwth=diff(log(hhdebt));
% ffr=ffr./100;
refi=refi./100;
lrhpriceshiller=log(hpshiller./pgdp);
hel=(heloc./debt);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%THRESHOLD %Defining state variable and threshold
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if thresholdd==1
    state=debttogdp;
    threshold=trend10e4*100;
elseif thresholdd==2
    state=debttogdp;
    threshold=trend10e5*100;
elseif thresholdd==3 % total private debt
    state=(hhdebt+corpdebt)./gdp*100;
    threshold=hpfilter(state, 10e4);
elseif thresholdd==4 %mortgage debt
    state=(debt)./gdp*100;
    threshold=hpfilter(state, 10e4);
elseif thresholdd==5 %2 percent above trend
    state=debttogdp;
    threshold=1.02*(trend10e4*100); 
elseif thresholdd==6
    state=hhdebtmvg5;
    threshold=prctile(hhdebtmvg5, 50);
elseif thresholdd==7
    state=recession;
    threshold=1;
elseif thresholdd==8
    threshold=(debttogdp-trend10e4*100)./trend10e4*100;
    z=(threshold-mean(threshold))/std(threshold);
    gam=3;
    fz=exp(gam*z)./(1+exp(gam*z));
%     fz=zeros(size(ffz));
%     fz(find(ffz>=0.6))=1;
end


if thresholdd==8
    fu=fz;
else
    % %Defining threshold for non-linear model
    rrr=find(state-threshold>=0);
    rrrn=rrr+1; %Since unemployment above threshold in the previous period is the criterion
    if rrrn(end)==length(state)+1
        rrrn=rrrn(1:end-1);
    else
        rrrn=rrrn;
    end
    fu=zeros(size(state));
    fu(rrrn)=1; % This is the dummy variable that defines the two states
size(rrr)/size(state)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if episode==1
    t11=find(q==1956.25); 
    t12=find(q==1968.75);
    fu(t11:t12)=0;
elseif episode ==2
    t11=find(q==1979); 
    t12=find(q==1980.75);
    fu(t11:t12)=0;
elseif episode ==3
    t11=find(q==1985.75); 
    t12=find(q==1992.5);
    fu(t11:t12)=0;
elseif episode ==4
    t11=find(q==2003.25); 
    t12=find(q==2007.75);
    fu(t11:t12)=0;
elseif episode ==0
    fu=fu;
end


    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X1=[ffr, lrgdp, inf];
%X1=[ffr];
lag1=0:1:nlag;
XLAG1 = lagmatrix(X1,lag1);
%X2=[lrgdp, inf, lrinv, lrcon, debttogdp log(hpshillerreal)];

lag2=1:1:nlag;
X2=[lrinv, lrcon, debttogdp log(hpshillerreal) lrhhdebt];
%X2=[lrinv, lrcon, lrhhdebt ];
XLAG2 = lagmatrix(X2,lag2);

X3=[lrcd, lrcnd, lrcs, lrresinv, lrnresinv ];
XLAG3 = lagmatrix(X3,lag2);

X4=[refi]; %hel
XLAG4 = lagmatrix(X4,lag2);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SHOCK IDENTIFICATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if shockchoice==1
    vardata=[lrgdp, lpgdp, ffr];
    dummy=[];
    dumb=0;
    nnlags=2;
    dlags=0;
    [F,FFF, V, err, X, Y ]=vectorautoregression(vardata,nnlags,dlags, dummy, dumb);
    Aoinv=chol(V)';
    identerror=Aoinv\err';
    shock=identerror(end,1+nlag-1:end)';
elseif shockchoice==2
    shock=ffr(nlag+2:end); % shock of interest
elseif shockchoice==3
    shock=rrshock(nlag+2:end);
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if datafile==1
    data=[X1(nlag+2:end,:), X2(nlag+2:end,:)];
elseif datafile==2
    data=[X1(nlag+2:end,:), X3(nlag+2:end,:)];
elseif datafile==3
    data=[X1(nlag+2:end,:), X4(nlag+2:end,:)];
end

xorig= XLAG1(nlag+2:end, 2:end); % exclude FFR

constant= ones(length(xorig),1);
t=1:1:length(xorig);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%LINEAR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x=[constant, t',  shock,  xorig];

rpos=3; %position of the shock
[dr,dsize]=size(data);
[r,nnn]=size(x);
for j=1:dsize
    y=data(:,j);
    if j>=4
        if datafile==1
            x=[x, XLAG2(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==2
            x=[x, XLAG3(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==3
            x=[x, XLAG4(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        end
    end
    [lin, se]=linlp(y,x,hor,rpos, opt);
    liny(j,:)=lin;
    sey(j,:)=se;
end

liny=liny./liny(1,1);
for j=1:dsize
    confidencey(1,:,j)=liny(j,:)-(sey(j,:)*clevel);
    confidencey(2,:,j)=liny(j,:)+(sey(j,:)*clevel);
end

liny=-liny;
confidencey=-confidencey;
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % %NON-LINEAR
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear x;

%x=[constant, shock,  xorig];
fu=fu(nlag+2:end);

[dr,dsize]=size(data);
for j=1:dsize
    y=data(:,j);
    if j>=4
        if datafile==1
            x=[xorig, XLAG2(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==2
            x=[xorig, XLAG3(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==3
            x=[xorig, XLAG4(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
            
        end
    else
        x=xorig;
    end
    x=[t', fu.*constant, (1-fu).*constant, fu.*shock, (1-fu).*shock, repmat(fu,1,size(x,2)).*x, repmat((1-fu),1,size(x,2)).*x];
    rpost=4;
    [statea, stateb, sea, seb]=statelp(y,x,hor,rpost, opt);
    seay(j,:)=sea;
    seby(j,:)=seb;
    stateay(j,:)=statea;
    stateby(j,:)=stateb;
end

stateay=stateay./stateay(1,1);
stateby=stateby./stateby(1,1);

for j=1:dsize
    confidenceya(1,:,j)=stateay(j,:)-(seay(j,:)*clevel);
    confidenceya(2,:,j)=stateay(j,:)+(seay(j,:)*clevel);
    confidenceyb(1,:,j)=stateby(j,:)-(seby(j,:)*clevel);
    confidenceyb(2,:,j)=stateby(j,:)+(seby(j,:)*clevel);
end

stateay=-stateay;
stateby=-stateby;
confidenceya=-confidenceya;
confidenceyb=-confidenceyb;

%save results_ep4.mat

