clear all
close all
clc

timesample=1; % 1 means 1955-2007; 2 means 1969-2007; 3 means 1955-2015
thresholdd=1;  % Check line 102 onwards % 1 means default threshold; 4 means mortgage debt as state variable; 5 means 2 percent above trend
shockchoice=3; % 1 means Romer-Romer shock; 2 means using FFR; 3 means SVAR shock
datafile=1; %1 means main set of variables; 2 means subcomponents of consumption and investment
opt=0; % 0 means Newey-West with bandwidth=i; 1 means optimal bandwidth (takes much longer to run)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
hor=16; % horizon for IRFs
clevel= 1.64; % confidence level % 1.96  1.64;
nlag=2;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
vdata=xlsread('data.xlsx');
time=vdata(:,1);

if timesample==1
    t1=find(time==1955); %1969
    t2=find(time==2007.75);
elseif timesample==2
    t1=find(time==1969);
    t2=find(time==2007.75);
elseif timesample==3
    t1=find(time==1955);
    t2=find(time==2015.5);
elseif timesample==4
    t1=find(time==1987);
    t2=find(time==2013.75);
elseif timesample==5
    t1=find(time==1990.75);
    t2=find(time==2015.5);
end


vdata=vdata(t1:t2,:);
q=vdata(:,1);
gdp= vdata(:,2); %GDP
cons= vdata(:,3); % CONS	
invest= vdata(:,4); %INVEST	
resinv= vdata(:,5); %RES_INVEST	
rgdp= vdata(:,6); %RGDP	
pgdp= vdata(:,7); %PGDP	
ffr= vdata(:,8); %FFR	
morrate= vdata(:,9); %MORT_RATE	
hrs= vdata(:,10); %HOURS	
wage= vdata(:,11); %WAGES	
% MORT_DEBT_LEVEL	
debt= vdata(:,12); %mortgage debt (level)
% MORT_DEBT_FLOW	
% HP_Case_Shiller	
% HP_Census_Bureau	
hprice= vdata(:,16);% HP_blend	
pop= vdata(:,17); %CNP16OV	
refi= vdata(:,18); %REFI
rrshock= vdata(:,19); %Romer-Romer monetary shock
hhdebt = vdata(:,20);
corpdebt = vdata(:,21);
recession=vdata(:,22);
trend10e6_old= vdata(:,26);% over sample excluding 2008-2015
trend10e4_old=vdata(:,27);% over sample excluding 2008-2015
pcom=vdata(:,28);
cdur=vdata(:,29);
cndur=vdata(:,30);
cserv=vdata(:,31);
nonresinv=vdata(:,32);
hpshiller=vdata(:,33);
hpshillerreal=vdata(:,34);
ffr= vdata(:,35); %include Wu-Xia shadow rate for 2008-2015
trend10e6= vdata(:,36);% over sample upto 2015
trend10e4= vdata(:,37);% over sample upto 2015
%pop=vdata(:,38); % Total population
hhdebtmvg5= vdata(:,39);
heloc=vdata(:,40)./1000;
trend10e5=vdata(:,42);

pcom_new=vdata(:,46);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA TRANSFORMATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
lrgdp= log(gdp./pgdp./pop);
lrcon=log(cons./pgdp./pop);
lrinv=log(invest./pgdp./pop);
lrresinv=log(resinv./pgdp./pop);
inf= [NaN; diff(log(pgdp))*400];
lrhprice=log(hprice./pgdp);
%lrdebt=log(debt./pgdp);
lrcd=log(cdur./pgdp./pop);
lrcnd=log(cndur./pgdp./pop);
lrcs=log(cserv./pgdp./pop);
lrnresinv=log(nonresinv./pgdp./pop);
lpcom=log(pcom_new);
lrhhdebt=log(hhdebt./pgdp);
lrcdebt=log(corpdebt./pgdp);
lpgdp=log(pgdp);
debttogdp=(hhdebt)./gdp*100;
cdebttogdp=(corpdebt./gdp)*100;
debtgrwth=diff(log(hhdebt));
% ffr=ffr./100;
refi=refi./100;
lrhpriceshiller=log(hpshiller./pgdp);
hel=(heloc./debt);
lrpcom=log(pcom_new./pgdp);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%THRESHOLD %Defining state variable and threshold
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if thresholdd==1
    state=debttogdp;
    threshold=trend10e4*100;
elseif thresholdd==2
    state=debttogdp;
    threshold=trend10e5*100;
elseif thresholdd==3 % total private debt
    state=(hhdebt+corpdebt)./gdp*100;
    threshold=hpfilter(state, 10e4);
elseif thresholdd==4 %mortgage debt
    state=(debt)./gdp*100;
    threshold=hpfilter(state, 10e4);
elseif thresholdd==5 %2 percent above trend
    state=debttogdp;
    threshold=1.02*(trend10e4*100); 
elseif thresholdd==6
    state=hhdebtmvg5;
    threshold=prctile(hhdebtmvg5, 50);
elseif thresholdd==7
    state=recession;
    threshold=1;
elseif thresholdd==8
    threshold=(debttogdp-trend10e4*100)./trend10e4*100;
    z=(threshold-mean(threshold))/std(threshold);
    gam=3;
    fz=exp(gam*z)./(1+exp(gam*z));
%     fz=zeros(size(ffz));
%     fz(find(ffz>=0.6))=1;
end


if thresholdd==8
    fu=fz;
else
    % %Defining threshold for non-linear model
    rrr=find(state-threshold>=0);
    rrrn=rrr+1; %Since unemployment above threshold in the previous period is the criterion
    if rrrn(end)==length(state)+1
        rrrn=rrrn(1:end-1);
    else
        rrrn=rrrn;
    end
    fu=zeros(size(state));
    fu(rrrn)=1; % This is the dummy variable that defines the two states
size(rrr)/size(state)
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X1=[ffr, lrgdp, inf];
%X1=[ffr];
lag1=0:1:nlag;
XLAG1 = lagmatrix(X1,lag1);
%X2=[lrgdp, inf, lrinv, lrcon, debttogdp log(hpshillerreal)];

lag2=1:1:nlag;
X2=[lrinv, lrcon, debttogdp lrcdebt];%cdebttogdp];
%X2=[lrinv, lrcon, lrhhdebt ];
XLAG2 = lagmatrix(X2,lag2);

X3=[lrcd, lrcnd, lrcs, lrresinv, lrnresinv ];
XLAG3 = lagmatrix(X3,lag2);

X4=[refi]; %hel
XLAG4 = lagmatrix(X4,lag2);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SHOCK IDENTIFICATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if shockchoice==1
    shock=rrshock(nlag+2:end);
elseif shockchoice==2
    shock=ffr(nlag+2:end); % shock of interest
elseif shockchoice==3
    vardata=[lrgdp, lpgdp, lrpcom, ffr];
    %vardata=[lrgdp, lpgdp, ffr];
    dummy=[];
    dumb=0;
    nnlags=2;
    dlags=0;
    [F,FFF, V, err, X, Y ]=vectorautoregression(vardata,nnlags,dlags, dummy, dumb);
    Aoinv=chol(V)';
    identerror=Aoinv\err';
    shock=identerror(end,1+nlag-1:end)';
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FIGURE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% gap=state-threshold;
% svarshock=[0;0;0;shock];
% data=[svarshock rrshock gap];
% 
% rrr=find(state>=threshold);  % Creating an indicator function with unemployment rate greater than some fixed threshold
% dummy=zeros(size(debttogdp));
% dummy(rrr)=1;
% 
% varnmz(1,:)='SVAR shock            ';
% varnmz(2,:)='Romer-Romer shock     ';
% varnmz(3,:)='Household debt gap    ';
% 
% 
% figure(12)
% for i=1:3
%     subplot(3,1,i)
%     area(q, dummy*max(data(:,i)),'FaceColor',[0.75 0.75 0.75],'EdgeColor','none')
%     hold on
%     area(q, dummy*min(data(:,i)),'FaceColor',[0.75 0.75 0.75],'EdgeColor','none')
%     hold on
%     plot(q, data(:,i), 'b', 'LineWidth', 1)
%     hold on
%     axis ([q(1,1), q(end,1), min(data(:,i)), max(data(:,i))])
%     title(varnmz(i,:));
%     
% end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if datafile==1
    data=[X1(nlag+2:end,:), X2(nlag+2:end,:)];
elseif datafile==2
    data=[X1(nlag+2:end,:), X3(nlag+2:end,:)];
elseif datafile==3
    data=[X1(nlag+2:end,:), X4(nlag+2:end,:)];
end

xorig= XLAG1(nlag+2:end, 2:end); % exclude FFR

constant= ones(length(xorig),1);
t=1:1:length(xorig);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%LINEAR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

x=[constant, t',  shock,  xorig];

rpos=3; %position of the shock
[dr,dsize]=size(data);
[r,nnn]=size(x);
for j=1:dsize
    y=data(:,j);
    if j>=4
        if datafile==1
            x=[x, XLAG2(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==2
            x=[x, XLAG3(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==3
            x=[x, XLAG4(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        end
    end
    [lin, se]=linlp(y,x,hor,rpos, opt);
    liny(j,:)=lin;
    sey(j,:)=se;
end

liny=liny./liny(1,1);
for j=1:dsize
    confidencey(1,:,j)=liny(j,:)-(sey(j,:)*clevel);
    confidencey(2,:,j)=liny(j,:)+(sey(j,:)*clevel);
end

liny=-liny;
confidencey=-confidencey;
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% % %NON-LINEAR
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear x;

%x=[constant, shock,  xorig];
fu=fu(nlag+2:end);

[dr,dsize]=size(data);
for j=1:dsize
    y=data(:,j);
    if j>=4
        if datafile==1
            x=[xorig, XLAG2(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==2
            x=[xorig, XLAG3(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
        elseif datafile==3
            x=[xorig, XLAG4(nlag+2:end,j-3)]; % in order to include the lag of the variable on RHS
            
        end
    else
        x=xorig;
    end
    x=[t', fu.*constant, (1-fu).*constant, fu.*shock, (1-fu).*shock, repmat(fu,1,size(x,2)).*x, repmat((1-fu),1,size(x,2)).*x];
    rpost=4;
    [statea, stateb, sea, seb]=statelp(y,x,hor,rpost, opt);
    seay(j,:)=sea;
    seby(j,:)=seb;
    stateay(j,:)=statea;
    stateby(j,:)=stateb;
end

stateay=stateay./stateay(1,1);
stateby=stateby./stateby(1,1);

for j=1:dsize
    confidenceya(1,:,j)=stateay(j,:)-(seay(j,:)*clevel);
    confidenceya(2,:,j)=stateay(j,:)+(seay(j,:)*clevel);
    confidenceyb(1,:,j)=stateby(j,:)-(seby(j,:)*clevel);
    confidenceyb(2,:,j)=stateby(j,:)+(seby(j,:)*clevel);
end

stateay=-stateay;
stateby=-stateby;
confidenceya=-confidenceya;
confidenceyb=-confidenceyb;

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if datafile==1
    names(1,:)=('      FFR           ');
    names(2,:)=('      GDP           ');
    names(3,:)=('  Inflation         ');
    names(4,:)=('   Investment       ');
    names(5,:)=('  Consumption       ');
    names(6,:)=('   HH Debt/GDP      ');
    names(7,:)=(' Log Corp. Debt     ');
    %names(7,:)=(' Corp. Debt/GDP     ');
    % % names(8,:)=('mortgage debt  ');
elseif datafile==2
    names(1,:)=('      FFR           ');
    names(2,:)=('      GDP           ');
    names(3,:)=('  Inflation         ');
    names(4,:)=('  Durable cons.     ');
    names(5,:)=(' Non-durable cons.  ');
    names(6,:)=('  Services cons.    ');
    names(7,:)=(' Residential inv.   ');
    names(8,:)=('Non-residential inv.');
elseif datafile==3
    names(1,:)=('      FFR           ');
    names(2,:)=('      GDP           ');
    names(3,:)=('  Inflation         ');
    %names(4,:)=('    House prices    ');
    names(4,:)=('    Refinancing     ');
    %names(4,:)=('    HELOCs          ');

end


rr=3;
cc=round(dsize/rr)+1;

zz=zeros(1,hor);
%figure(4)
figure1 = figure;
% figure(4)
for j=1:dsize
subplot(dsize,3,3*j-2)
plot(1:1:hor, zz, 'k-')
hold on
plot(1:1:hor, liny(j,:), 'k','LineWidth', 1.5)
hold on
plot(1:1:hor, stateay(j,:),'b--', 'LineWidth',1.5)
hold on
plot(1:1:hor, stateby(j,:), 'r-.', 'LineWidth', 1.5)
axis tight
ylabel(names(j,:))

subplot(dsize,3,(3*j-2)+1)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidencey(1,:,j)'; (hor:-1:1)' confidencey(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, zz, 'k-')
plot(1:1:hor, liny(j,:), 'k','LineWidth', 1.5)
%ylabel('Linear')
axis tight

subplot(dsize,3,(3*j-2)+2)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidenceya(1,:,j)'; (hor:-1:1)' confidenceya(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, stateay(j,:), 'b--','LineWidth', 1.5)
hold on
plot(1:1:hor, stateby(j,:), 'r-.', 1:1:hor, confidenceyb(1,:,j), 'r--', 1:1:hor, confidenceyb(2,:,j), 'r--', 'LineWidth', 1.5);
hold on
plot(1:1:hor, zz, 'k-')
axis tight
% %ylabel('State-dependent')
% %xlabel('quarter')
% title(names(j,:))

end
% Create textbox
annotation(figure1,'textbox',...
    [0.487012987012988 0.917161434977579 0.099025974025974 0.031390134529148],...
    'String',{'Linear'},...
    'LineStyle','none');

% Create textbox
annotation(figure1,'textbox',...
    [0.707792207792209 0.919403587443946 0.199675324675325 0.031390134529148],...
    'String',{'State Dependent'},...
    'LineStyle','none');

zz=zeros(1,hor);
figure2 = figure;
for j=4:dsize
subplot(dsize-3,3,3*(j-3)-2)
plot(1:1:hor, zz, 'k-')
hold on
plot(1:1:hor, liny(j,:), 'k','LineWidth', 1.5)
hold on
plot(1:1:hor, stateay(j,:),'b--', 'LineWidth',1.5)
hold on
plot(1:1:hor, stateby(j,:), 'r-.', 'LineWidth', 1.5)
axis tight
ylabel(names(j,:))
subplot(dsize-3,3,(3*(j-3)-2)+1)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidencey(1,:,j)'; (hor:-1:1)' confidencey(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, zz, 'k-')
plot(1:1:hor, liny(j,:), 'k','LineWidth', 1.5)
%ylabel('Linear')
axis tight
subplot(dsize-3,3,(3*(j-3)-2)+2)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidenceya(1,:,j)'; (hor:-1:1)' confidenceya(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, stateay(j,:), 'b--','LineWidth', 1.5)
hold on
plot(1:1:hor, stateby(j,:), 'r-.', 1:1:hor, confidenceyb(1,:,j), 'r--', 1:1:hor, confidenceyb(2,:,j), 'r--', 'LineWidth', 1.5);
hold on
plot(1:1:hor, zz, 'k-')
axis tight
% %ylabel('State-dependent')
% %xlabel('quarter')
% title(names(j,:))
end
% Create textbox
annotation(figure2,'textbox',...
    [0.487012987012988 0.917161434977579 0.099025974025974 0.031390134529148],...
    'String',{'Linear'},...
    'LineStyle','none');

% Create textbox
annotation(figure2,'textbox',...
    [0.707792207792209 0.919403587443946 0.199675324675325 0.031390134529148],...
    'String',{'State Dependent'},...
    'LineStyle','none');


sumstatea=cumsum(stateay,2);
sumstateb=cumsum(stateby,2);
disp('Cumulative impact on variables of monetary shock')
disp('4qtr, 8qtr, 12qtr, 16qtr')

VariableNames={'      FFR           ';'                    ';'      GDP           ';'                    ';'  Inflation         ';'                    ';'   Investment       ';'                    ';'  Consumption       ';'                    ';'   Debt/GDP         ';'                    ';'    House prices    ';'                    '};

figure(23)
for j=1:dsize
subplot(4,2,j)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidencey(1,:,j)'; (hor:-1:1)' confidencey(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, zz, 'k-')
plot(1:1:hor, liny(j,:), 'k','LineWidth', 1.5)
%ylabel('Linear')
axis tight
title(names(j,:))
end

figure(24)
for j=1:dsize
subplot(4,2,j)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidenceya(1,:,j)'; (hor:-1:1)' confidenceya(2,hor:-1:1,j)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, stateay(j,:), 'b--','LineWidth', 1.5)
hold on
plot(1:1:hor, stateby(j,:), 'r-.', 1:1:hor, confidenceyb(1,:,j), 'r--', 1:1:hor, confidenceyb(2,:,j), 'r--', 'LineWidth', 1.5);
hold on
plot(1:1:hor, zz, 'k-')
axis tight
title(names(j,:))
end


figure(25)
for j=1:dsize-3
subplot(3,2,j)
plot(1:1:hor, zz, 'k-')
hold on
grpyat=[(1:1:hor)', confidenceya(1,:,j+3)'; (hor:-1:1)' confidenceya(2,hor:-1:1,j+3)'];
patch(grpyat(:,1), grpyat(:,2), [0.7 0.7 0.7],'edgecolor', [0.7 0.7 0.7]);
plot(1:1:hor, stateay(j+3,:), 'b--','LineWidth', 1.5)
hold on
plot(1:1:hor, stateby(j+3,:), 'r-.', 1:1:hor, confidenceyb(1,:,j+3), 'r--', 1:1:hor, confidenceyb(2,:,j+3), 'r--', 'LineWidth', 1.5);
hold on
plot(1:1:hor, zz, 'k-')
axis tight
title(names(j+3,:))
end

figure(3)
for kk=1:dsize
    subplot(dsize,2,2*kk-1)
    plot(1:1:hor, sumstatea(kk,:), 'b--', 1:1:hor, sumstateb(kk,:),'r-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
subplot(dsize,2,2*kk)
plot(1:1:hor, sumstatea(kk,:)./-sumstatea(1,:), 'b--', 1:1:hor, sumstateb(kk,:)./-sumstateb(1,:),'r-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
end


figure(4)
for kk=1:dsize
    subplot(4,2,kk)
    plot(1:1:hor, sumstatea(kk,:), 'b--', 1:1:hor, sumstateb(kk,:),'r-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
end

figure(6)
for kk=1:dsize
subplot(4,2,kk)
plot(1:1:hor, sumstatea(kk,:)./-sumstatea(1,:), 'b--', 1:1:hor, sumstateb(kk,:)./-sumstateb(1,:),'r-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
end


j=5;
for j=1:dsize
L(j,:)=cumsum(liny(j,:))./cumsum(liny(1,:));
end
for j=1:dsize
R(j,:)=cumsum(stateay(j,:))./cumsum(stateay(1,:));
end
for j=1:dsize
E(j,:)=cumsum(stateby(j,:))./cumsum(stateby(1,:));
end

[L(2,:)', E(2,:)', R(2,:)']



load recessionstatea;
recsumstatea= cumsum(recessionstatea,2);

figure(5)
for kk=1:dsize
    subplot(7,2,2*kk-1)
    plot(1:1:hor, sumstatea(kk,:), 'b--', 1:1:hor, recsumstatea(kk,:),'k-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
subplot(7,2,2*kk)
plot(1:1:hor, sumstatea(kk,:)./-sumstatea(1,:), 'b--', 1:1:hor, recsumstatea(kk,:)./-recsumstatea(1,:),'k-.', 'LineWidth', 1.5)
title(names(kk,:))
axis tight
end